<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Form;

use Dedi\SyliusBlogPlugin\Entity\Article;
use Dedi\SyliusBlogPlugin\Entity\Author;
use Dedi\SyliusBlogPlugin\Entity\Category;
use Dedi\SyliusBlogPlugin\Entity\TypeArticle;
use Sylius\Bundle\ChannelBundle\Form\Type\ChannelChoiceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Valid;

class ArticleType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('enabled', CheckboxType::class, [
                'label' => 'dedi_blog.form.enabled',
            ])
            ->add('author', EntityType::class, [
                'class' => Author::class,
                'multiple' => false,
                'choice_name' => 'username',
                'choice_value' => 'id',
                'by_reference' => false,
                'required' => false,
                'label' => 'dedi_blog.form.article.author',
            ])
            ->add('position', NumberType::class, [
                'html5' => true,
                'attr' => ['min' => 0, 'step' => 1],
                'label' => 'dedi_blog.form.article.position',
            ])
            ->add('banner', ArticleBannerType::class, [
                'required' => false,
                'label' => 'dedi_blog.form.article.banner',
            ])
            ->add('channels', ChannelChoiceType::class, [
                'multiple' => true,
                'expanded' => true,
                'label' => 'dedi_blog.form.channels',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => ArticleTranslationType::class,
                'constraints' => [new Valid()],
            ])

            ->add('categories', EntityType::class, [
                'class' => Category::class,
                'multiple' => true,
                'choice_name' => 'name',
                'choice_value' => 'id',
                'required' => false,
                'label' => 'dedi_blog.form.article.categories',
            ])

            ->add('type', EntityType::class, [
                'class' => TypeArticle::class,
                'label' => 'dedi_blog.ui.article_type',
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => Article::class,
            'validation_groups' => ['default', 'sylius'],
        ]);
    }
}
